.. Written by Konrad Hinsen
.. License: CC-BY 3.0

Mosaic Python Library
=====================

.. toctree::
   :maxdepth: 1

   python_api

Mosaic tools
============

.. toctree::
   :maxdepth: 1

   tools

Mosaic specification
====================

.. toctree::
   :maxdepth: 1

   data_model
   xml
   hdf5
   pdb_convention

Indices
=======

* :ref:`genindex`
* :ref:`modindex`

